// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package migration

import (
	"embed"

	"github.com/golang-migrate/migrate/v4"
	"github.com/golang-migrate/migrate/v4/database/postgres"
	"github.com/golang-migrate/migrate/v4/source"
	"github.com/golang-migrate/migrate/v4/source/iofs"
	"github.com/orus-io/yago"
)

//go:embed scripts/*.sql
var assets embed.FS

// New returns a migrate instance for migrating the given database
func New(db *yago.DB) (*migrate.Migrate, source.Driver, error) {
	source, err := iofs.New(assets, "scripts")
	if err != nil {
		return nil, nil, err
	}
	database, err := postgres.WithInstance(db.Engine.DB().DB, &postgres.Config{})
	if err != nil {
		return nil, nil, err
	}
	m, err := migrate.NewWithInstance(
		"embedded", source,
		"postgres", database,
	)
	return m, source, err
}
