package api

import (
	"unsafe"

	"github.com/rs/zerolog"
)

func (x *ProcessingContext) MarshalZerologObject(e *zerolog.Event) {
	e.
		Str("process_id", x.GetProcessIDAsUUID().String()).
		Str("node_id", x.NodeID)
}

func (x *Envelope) MarshalZerologObject(e *zerolog.Event) {
	if id := x.GetIDAsUUID(); !id.IsZero() {
		e.Stringer("id", id)
	}

	e.Bool("last", x.Last)

	arr := zerolog.Arr()
	for _, id := range x.GetEventIDsAsUUIDSlice() {
		arr.Str(id.String())
	}
	e.Array("event_ids", arr)

	arr = zerolog.Arr()
	for _, event := range x.GetEvents() {
		arr.Dict(zerolog.Dict().
			Stringer("id", event.GetIDAsUUID()).
			Str("eventtype", event.GetType()).
			Hex("checksum", (*[4]byte)(unsafe.Pointer(&event.Checksum))[:]).
			Uint64("index", event.GetIndex()).
			Uint64("item-count", event.GetItemCount()).
			Int("items-len", len(event.Items)),
		)
	}
	e.Array("events", arr)
}
